/*
 Displaying a string that contains a period on a seven-segment display.
 Contributed by Matthew Nielsen (github.com/xunker) for the SevSeg Arduino
 Library (github.com/DeanIsMe/SevSeg) by Dean Reading.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

#include "SevSeg.h"
SevSeg sevseg; //Instantiate a seven segment controller object

#define MAX_NUMBER_STRINGS 12
#define MAX_STRING_SIZE 8
char testStrings[MAX_NUMBER_STRINGS][MAX_STRING_SIZE];

#define PATTERN_CHANGE_TIME 1000
unsigned long timer = millis() - PATTERN_CHANGE_TIME;
byte testStringsPos = 0;

void setup() {
byte hardwareConfig = COMMON_ANODE; // See SevSeg README.md for options
byte numDigits = 4;
byte digitPins[] = {16,17,3,4}; //Digits 1-4
byte segmentPins[]={8, 14, 6, A1, 23, 7, 5, 22}; // segments A-E and Decimal
bool resistorsOnSegments = true; // 'false' means resistors are on digit pins
bool updateWithDelays = false; // Default 'false' is Recommended
bool leadingZeros = false; // Use 'true' if you'd like to keep the leading zeros
bool disableDecPoint = false; // Use 'true' if your decimal point doesn't exist or isn't connected. Then, you only need to specify 7 segmentPins[]

  sevseg.begin(hardwareConfig, numDigits, digitPins, segmentPins, resistorsOnSegments, updateWithDelays, leadingZeros);
  sevseg.setBrightness(90);

  // Adds set of test strings with periods in various places
  strcpy(testStrings[0], "NERF");
  strcpy(testStrings[1], "N.ERF");
  strcpy(testStrings[2], "N.E.RF");
  strcpy(testStrings[3], "N.E.R.F");
  strcpy(testStrings[4], "N.E.R.F.");
  strcpy(testStrings[5], "NE.R.F.");
  strcpy(testStrings[6], "NER.F.");
  strcpy(testStrings[7], "NERF.");
  strcpy(testStrings[8], "NERF");
  strcpy(testStrings[9], ". . . ");
  strcpy(testStrings[10], ". . . .");
  strcpy(testStrings[11], ". . ."); 
}

void loop() {

  // Cycle to the next string every one second
  if (millis() > (timer + PATTERN_CHANGE_TIME)) {
    sevseg.setChars(testStrings[testStringsPos]);
    testStringsPos++;
    if (testStringsPos >= MAX_NUMBER_STRINGS) testStringsPos = 0;
    timer = millis();
  }

  sevseg.refreshDisplay(); // Must run repeatedly
}

/// END ///
